<?php
/**
 * Weeland Customizer support
 *
 * @package WordPress
 * @since Weeland 1.0
 */
 
/**
 * Implement Customizer additions and adjustments.
 *
 * @since Weeland 1.0
 *
 * @param WP_Customize_Manager $wp_customize Customizer object.
 */
function weeland_customize_register( $wp_customize ) {
  /*
   * Modify default Wordpress sections and controls
   */
  $wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
  $wp_customize->get_setting( 'background_color' )->transport = 'postMessage';
	$wp_customize->get_control( 'blogdescription' )->label = esc_html__( 'Site Description', 'weeland' );
  $wp_customize->get_control( 'custom_logo' )->priority = 0;
  $wp_customize->get_control( 'blogname' )->priority = 10;
  $wp_customize->get_control( 'blogdescription' )->priority = 20;
  $wp_customize->get_section( 'header_image' )->title = esc_html__( 'Sidebar Image', 'weeland' );
	$wp_customize->remove_control('display_header_text');
  $wp_customize->remove_control('header_textcolor');
  /*
   * Site Title & Tagline
   */   

  $wp_customize->add_setting( 'logo_size',
    array(
      'default' => 200,
      'sanitize_callback' => 'weeland_logo_size_sanitize',
      'transport' => 'postMessage'
    )
  );
  
  $wp_customize->add_control( 'logo_size', array(
    'type'        => 'range',
    'priority'    => 5,
    'section'     => 'title_tagline',
    'label'       => esc_html__( 'Logo Size', 'weeland' ),
    'input_attrs' => array(
        'min'   => 50,
        'max'   => 500,
        'step'  => 10
    ),
  ) );

  $wp_customize->add_setting( 'display_site_title',
    array(
      'default' => 1,
      'sanitize_callback' => 'weeland_checkbox_sanitize'
    )
  );
  
  $wp_customize->add_control( 'display_site_title', array(
    'type'     => 'checkbox',
    'priority' => 15,
    'label'    => esc_html__( 'Display Site Title', 'weeland' ),
    'section'  => 'title_tagline',
  ) );
  
  $wp_customize->add_setting(
    'tagline',
    array(
      'default' => '',
      'sanitize_callback' => 'weeland_textarea_sanitize',
      'transport' => 'postMessage'
    )
  );
 
  $wp_customize->add_control(
      'tagline',
      array(
        'type'        => 'textarea',
        'priority' => 25,
        'label'       => esc_html__( 'Tagline', 'weeland' ),
        'description' => esc_html__( 'You may use these HTML tags and attributes: a[href,title], p, b, strong, em, i, br, span, img[src, alt, title]', 'weeland' ),
        'section'     => 'title_tagline',
      )
  );

  /*
   * Header Image
   */
  $wp_customize->add_setting( 'sidebar_image_blackout',
    array(
      'default' => 0.35,
      'sanitize_callback' => 'weeland_blackout_sanitize',
      'transport' => 'postMessage'
    )
  );
  
  $wp_customize->add_control( 'sidebar_image_blackout', array(
    'type'      => 'range',
    'section'   => 'header_image',
    'label'     => esc_html__( 'Blackout', 'weeland' ),
    'priority'  => 30,
    'input_attrs' => array(
        'min'   => 0,
        'max'   => 1,
        'step'  => 0.05
    ),
  ) );

    $wp_customize->add_setting( 'mobile_sidebar_image',
    array(
      'default' => '',
      'sanitize_callback' => 'absint'
    )
  );

  $wp_customize->add_control( 
    new WP_Customize_Cropped_Image_Control( $wp_customize, 'mobile_sidebar_image', array(
    'section'     => 'header_image',
    'label'       => esc_html__( 'Image for mobile devices (optional)', 'weeland' ),
    'flex_width'  => true,
    'flex_height' => true,
    'width'       => 1000,
    'height'      => 600
    ) ) 
  );

  /*
   * Colors
   */
  
  $wp_customize->add_setting( 'link_color',
    array(
      'default' => '#c8ab77',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );
  
  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'link_color',
          array(
              'label' => esc_html__( 'Links', 'weeland' ),
              'section' => 'colors',
              'settings' => 'link_color',
          )
      )
  ); 

  $wp_customize->add_setting( 'link_color_hover',
    array(
      'default' => '#a9874a',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'link_color_hover',
          array(
              'label' => esc_html__( 'Links (hover)', 'weeland' ),
              'section' => 'colors',
              'settings' => 'link_color_hover',
          )
      )
  );  
  
  $wp_customize->add_setting( 'button_background_color',
    array(
      'default' => '#cbb78f',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );
  
  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'button_background_color',
          array(
              'label' => esc_html__( 'Buttons', 'weeland' ),
              'section' => 'colors',
              'settings' => 'button_background_color',
          )
      )
  ); 
  
  $wp_customize->add_setting( 'button_background_color_hover',
    array(
      'default' => '#bba579',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );
  
  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'button_background_color_hover',
          array(
              'label' => esc_html__( 'Buttons (hover)', 'weeland' ),
              'section' => 'colors',
              'settings' => 'button_background_color_hover',
          )
      )
  ); 
  
  $wp_customize->add_setting( 'button_text_color',
    array(
      'default' => '#ffffff',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );
  
  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'button_text_color',
          array(
              'label' => esc_html__( 'Buttons Text', 'weeland' ),
              'section' => 'colors',
              'settings' => 'button_text_color',
          )
      )
  ); 

  $wp_customize->add_setting( 'category_underline_color',
    array(
      'default' => '#f1f1f1',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );
  
  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'category_underline_color',
          array(
              'label' => esc_html__( 'Category Underline', 'weeland' ),
              'section' => 'colors',
              'settings' => 'category_underline_color',
          )
      )
  ); 

  $wp_customize->add_setting( 'pagination_current_page_color',
    array(
      'default' => '#d3c4a6',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );
  
  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'pagination_current_page_color',
          array(
              'label' => esc_html__( 'Pagination (current/hover)', 'weeland' ),
              'section' => 'colors',
              'settings' => 'pagination_current_page_color',
          )
      )
  ); 
  
  /*
   * Social Profiles
   */ 
  $wp_customize->add_section( 'social',
    array(
      'title' => esc_html__( 'Social Profiles', 'weeland' )
    )
  );

  $wp_customize->add_setting( 'social[facebook]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[facebook]', array(
    'type'     => 'url',
    'priority' => 10,
    'section'  => 'social',
    'label'    => esc_html__( 'Facebook', 'weeland' ),
  ) );
  
  $wp_customize->add_setting( 'social[twitter]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[twitter]', array(
    'type'     => 'url',
    'priority' => 15,
    'section'  => 'social',
    'label'    => esc_html__( 'Twitter', 'weeland' ),
  ) );
  
  $wp_customize->add_setting( 'social[googleplus]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[googleplus]', array(
    'type'     => 'url',
    'priority' => 20,
    'section'  => 'social',
    'label'    => esc_html__( 'Google Plus', 'weeland' ),
  ) );
  
  $wp_customize->add_setting( 'social[bloglovin]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[bloglovin]', array(
    'type'     => 'url',
    'priority' => 20,
    'section'  => 'social',
    'label'    => esc_html__( 'Bloglovin', 'weeland' ),
  ) );
  
  $wp_customize->add_setting( 'social[instagram]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[instagram]', array(
    'type'     => 'url',
    'priority' => 25,
    'section'  => 'social',
    'label'    => esc_html__( 'Instagram', 'weeland' ),
  ) );
  
  $wp_customize->add_setting( 'social[pinterest]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[pinterest]', array(
    'type'     => 'url',
    'priority' => 30,
    'section'  => 'social',
    'label'    => esc_html__( 'Pinterest', 'weeland' ),
  ) );
  
  $wp_customize->add_setting( 'social[linkedin]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[linkedin]', array(
    'type'     => 'url',
    'priority' => 35,
    'section'  => 'social',
    'label'    => esc_html__( 'LinkedIn', 'weeland' ),
  ) );
  
  $wp_customize->add_setting( 'social[flickr]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[flickr]', array(
    'type'     => 'url',
    'priority' => 40,
    'section'  => 'social',
    'label'    => esc_html__( 'Flickr', 'weeland' ),
  ) );
  
  $wp_customize->add_setting( 'social[medium]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[medium]', array(
    'type'     => 'url',
    'priority' => 45,
    'section'  => 'social',
    'label'    => esc_html__( 'Medium', 'weeland' ),
  ) );
  
  $wp_customize->add_setting( 'social[vkontakte]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[vkontakte]', array(
    'type'     => 'url',
    'priority' => 50,
    'section'  => 'social',
    'label'    => esc_html__( 'Vkontakte', 'weeland' ),
  ) );
  
  $wp_customize->add_setting( 'social[f500px]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[f500px]', array(
    'type'     => 'url',
    'priority' => 55,
    'section'  => 'social',
    'label'    => esc_html__( '500px', 'weeland' ),
  ) );
  
  $wp_customize->add_setting( 'social[tumblr]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[tumblr]', array(
    'type'     => 'url',
    'priority' => 60,
    'section'  => 'social',
    'label'    => esc_html__( 'Tumblr', 'weeland' ),
  ) );
  
  $wp_customize->add_setting( 'social[dribbble]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[dribbble]', array(
    'type'     => 'url',
    'priority' => 65,
    'section'  => 'social',
    'label'    => esc_html__( 'Dribbble', 'weeland' ),
  ) );
  
  $wp_customize->add_setting( 'social[behance]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[behance]', array(
    'type'     => 'url',
    'priority' => 70,
    'section'  => 'social',
    'label'    => esc_html__( 'Behance', 'weeland' ),
  ) );
  
  $wp_customize->add_setting( 'social[youtube]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[youtube]', array(
    'type'     => 'url',
    'priority' => 75,
    'section'  => 'social',
    'label'    => esc_html__( 'YouTube', 'weeland' ),
  ) );
  
  $wp_customize->add_setting( 'social[vimeo]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[vimeo]', array(
    'type'     => 'url',
    'priority' => 80,
    'section'  => 'social',
    'label'    => esc_html__( 'Vimeo', 'weeland' ),
  ) );
  
  $wp_customize->add_setting( 'social[github]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[github]', array(
    'type'     => 'url',
    'priority' => 85,
    'section'  => 'social',
    'label'    => esc_html__( 'Github', 'weeland' ),
  ) );
  
  $wp_customize->add_setting( 'social[soundcloud]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[soundcloud]', array(
    'type'     => 'url',
    'priority' => 90,
    'section'  => 'social',
    'label'    => esc_html__( 'SoundCloud', 'weeland' ),
  ) );
  
  $wp_customize->add_setting( 'social[rss]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[rss]', array(
    'type'     => 'url',
    'priority' => 95,
    'section'  => 'social',
    'label'    => esc_html__( 'Rss', 'weeland' ),
  ) );

  $wp_customize->add_setting( 'social[etsy]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[etsy]', array(
    'type'     => 'url',
    'priority' => 100,
    'section'  => 'social',
    'label'    => esc_html__( 'Etsy', 'weeland' ),
  ) );

  $wp_customize->add_setting( 'social[steam]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[steam]', array(
    'type'     => 'url',
    'priority' => 105,
    'section'  => 'social',
    'label'    => esc_html__( 'Steam', 'weeland' ),
  ) );

  $wp_customize->add_setting( 'social[snapchat]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[snapchat]', array(
    'type'     => 'url',
    'priority' => 110,
    'section'  => 'social',
    'label'    => esc_html__( 'Snapchat', 'weeland' ),
  ) );

  $wp_customize->add_setting( 'social[twitch]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[twitch]', array(
    'type'     => 'url',
    'priority' => 115,
    'section'  => 'social',
    'label'    => esc_html__( 'Twitch', 'weeland' ),
  ) );

  $wp_customize->add_setting( 'social[quora]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[quora]', array(
    'type'     => 'url',
    'priority' => 120,
    'section'  => 'social',
    'label'    => esc_html__( 'Quora', 'weeland' ),
  ) );

  $wp_customize->add_setting( 'social[odnoklassniki]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[odnoklassniki]', array(
    'type'     => 'url',
    'priority' => 125,
    'section'  => 'social',
    'label'    => esc_html__( 'Odnoklassniki', 'weeland' ),
  ) );

  $wp_customize->add_setting( 'social[reddit]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[reddit]', array(
    'type'     => 'url',
    'priority' => 130,
    'section'  => 'social',
    'label'    => esc_html__( 'Reddit', 'weeland' ),
  ) );

  $wp_customize->add_setting( 'social[xing]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[xing]', array(
    'type'     => 'url',
    'priority' => 135,
    'section'  => 'social',
    'label'    => esc_html__( 'Xing', 'weeland' ),
  ) );
  
  $wp_customize->add_setting( 'social[weibo]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );

  $wp_customize->add_control( 'social[weibo]', array(
    'type'     => 'url',
    'priority' => 135,
    'section'  => 'social',
    'label'    => esc_html__( 'Weibo', 'weeland' ),
  ) );

  $wp_customize->add_setting( 'social[renren]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );

  $wp_customize->add_control( 'social[renren]', array(
    'type'     => 'url',
    'priority' => 140,
    'section'  => 'social',
    'label'    => esc_html__( 'Renren', 'weeland' ),
  ) );
  
  $wp_customize->add_setting( 'social[email]',
    array(
      'default' => '',
      'sanitize_callback' => 'weeland_email_sanitize'
    )
  );
  
  $wp_customize->add_setting( 'social[email]',
    array(
      'default' => '',
      'sanitize_callback' => 'weeland_email_sanitize'
    )
  );
  
  $wp_customize->add_control( 'social[email]', array(
    'type'     => 'url',
    'priority' => 150,
    'section'  => 'social',
    'label'    => esc_html__( 'Email', 'weeland' ),
  ) );
   
  /*
   * Post Options
   */
  $wp_customize->add_section( 'post_options',
    array(
      'title' => esc_html__( 'Post Options', 'weeland' )
    )
  ); 
  
  $wp_customize->add_setting( 'display_categories',
    array(
      'default' => 1,
      'sanitize_callback' => 'weeland_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_categories', array(
    'type'     => 'checkbox',
    'priority' => 0,
    'label'    => esc_html__( 'Display category', 'weeland' ),
    'section'  => 'post_options',
  ) );
  
  $wp_customize->add_setting( 'display_date',
    array(
      'default' => 1,
      'sanitize_callback' => 'weeland_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_date', array(
    'type'     => 'checkbox',
    'priority' => 0,
    'label'    => esc_html__( 'Display post date', 'weeland' ),
    'section'  => 'post_options',
  ) );
  
  $wp_customize->add_setting( 'display_tags_list',
    array(
      'default' => 1,
      'sanitize_callback' => 'weeland_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_tags_list', array(
    'type'     => 'checkbox',
    'priority' => 0,
    'label'    => esc_html__( 'Display tags', 'weeland' ),
    'section'  => 'post_options',
  ) );
  
  $wp_customize->add_setting( 'display_share_buttons',
    array(
      'default' => 1,
      'sanitize_callback' => 'weeland_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_share_buttons', array(
    'type'     => 'checkbox',
    'priority' => 0,
    'label'    => esc_html__( 'Display share buttons', 'weeland' ),
    'section'  => 'post_options',
  ) );
  
  $wp_customize->add_setting( 'display_author',
    array(
      'default' => 1,
      'sanitize_callback' => 'weeland_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_author', array(
    'type'     => 'checkbox',
    'priority' => 0,
    'label'    => esc_html__( 'Display author name', 'weeland' ),
    'section'  => 'post_options'
  ) );

  $wp_customize->add_setting( 'display_post_navigation',
    array(
      'default' => 1,
      'sanitize_callback' => 'weeland_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_post_navigation', array(
    'type'     => 'checkbox',
    'priority' => 0,
    'label'    => esc_html__( 'Display Previous/Next post', 'weeland' ),
    'section'  => 'post_options'
  ) );

  $wp_customize->add_setting( 'display_related_posts',
    array(
      'default' => 1,
      'sanitize_callback' => 'weeland_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_related_posts', array(
    'type'     => 'checkbox',
    'priority' => 0,
    'label'    => esc_html__( 'Display related posts', 'weeland' ),
    'section'  => 'post_options'
  ) );

  $wp_customize->add_setting(
    'related_by',
    array(
      'default' => 'none',
      'sanitize_callback' => 'weeland_related_by_sanitize',
    )
  );
  
  $wp_customize->add_control(
      'related_by',
      array(
        'type'    => 'select',
        'priority' => 40,
        'label'   => esc_html__( 'Related posts', 'weeland' ),
        'section' => 'post_options',
        'choices' => array(
          'category' => esc_html__( 'by category', 'weeland' ),
          'tags'     => esc_html__( 'by tags', 'weeland' ),
          'none'     => esc_html__( 'random', 'weeland' )
        )
      )
  );

  /*
   * Post Options
   */
  $wp_customize->add_section( 'posts_grid_options',
    array(
      'title' => esc_html__( 'Posts Grid Options', 'weeland' )
    )
  ); 

  $wp_customize->add_setting( 'display_grid_thumbnail',
    array(
      'default' => 1,
      'sanitize_callback' => 'weeland_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_grid_thumbnail', array(
    'type'     => 'checkbox',
    'priority' => 0,
    'label'    => esc_html__( 'Display post thumbnail', 'weeland' ),
    'section'  => 'posts_grid_options',
  ) );

  $wp_customize->add_setting( 'display_grid_title',
    array(
      'default' => 1,
      'sanitize_callback' => 'weeland_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_grid_title', array(
    'type'     => 'checkbox',
    'priority' => 0,
    'label'    => esc_html__( 'Display title', 'weeland' ),
    'section'  => 'posts_grid_options',
  ) );
  
  $wp_customize->add_setting( 'display_grid_categories',
    array(
      'default' => 1,
      'sanitize_callback' => 'weeland_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_grid_categories', array(
    'type'     => 'checkbox',
    'priority' => 0,
    'label'    => esc_html__( 'Display category', 'weeland' ),
    'section'  => 'posts_grid_options',
  ) );
  
  $wp_customize->add_setting( 'display_grid_date',
    array(
      'default' => 1,
      'sanitize_callback' => 'weeland_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_grid_date', array(
    'type'     => 'checkbox',
    'priority' => 0,
    'label'    => esc_html__( 'Display post date', 'weeland' ),
    'section'  => 'posts_grid_options',
  ) );
  
  $wp_customize->add_setting( 'display_grid_author',
    array(
      'default' => 1,
      'sanitize_callback' => 'weeland_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_grid_author', array(
    'type'     => 'checkbox',
    'priority' => 0,
    'label'    => esc_html__( 'Display author name', 'weeland' ),
    'section'  => 'posts_grid_options'
  ) );

  $wp_customize->add_setting( 'display_grid_summary',
    array(
      'default' => 'excerpt',
      'sanitize_callback' => 'weeland_grid_summary_sanitize',
    )
  );

  $wp_customize->add_control(
    'display_grid_summary', 
    array(
      'label'    => esc_html__( 'Summary', 'weeland' ),
      'section'  => 'posts_grid_options',
      'settings' => 'display_grid_summary',
      'type'     => 'radio',
      'choices'  => array(
        'excerpt' => esc_html__( 'Auto or excerpt field', 'weeland' ),
        'more'    => esc_html__( 'More tag', 'weeland' ),
        'disable'    => esc_html__( 'Disable', 'weeland' )
      ),
    )
  );
  
  /*
   * Page Options
   */
  $wp_customize->add_section( 'page_options',
    array(
      'title' => esc_html__( 'Page Options', 'weeland' )
    )
  ); 
  
  $wp_customize->add_setting( 'display_page_share_buttons',
    array(
      'default' => 1,
      'sanitize_callback' => 'weeland_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_page_share_buttons', array(
    'type'     => 'checkbox',
    'priority' => 0,
    'label'    => esc_html__( 'Display share buttons', 'weeland' ),
    'section'  => 'page_options',
  ) );
  
  /*
   * Share Buttons
   */
  $wp_customize->add_section( 'share_buttons',
    array(
      'title' => esc_html__( 'Share Buttons', 'weeland' )
    )
  ); 
  
  $wp_customize->add_setting( 'display_facebook_share_button',
    array(
      'default' => 1,
      'sanitize_callback' => 'weeland_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_facebook_share_button', array(
    'type'     => 'checkbox',
    'priority' => 0,
    'label'    => esc_html__( 'Facebook', 'weeland' ),
    'section'  => 'share_buttons',
  ) );
  
  $wp_customize->add_setting( 'display_twitter_share_button',
    array(
      'default' => 1,
      'sanitize_callback' => 'weeland_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_twitter_share_button', array(
    'type'     => 'checkbox',
    'priority' => 5,
    'label'    => esc_html__( 'Twitter', 'weeland' ),
    'section'  => 'share_buttons',
  ) );
  
  $wp_customize->add_setting( 'display_google_share_button',
    array(
      'default' => 1,
      'sanitize_callback' => 'weeland_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_google_share_button', array(
    'type'     => 'checkbox',
    'priority' => 10,
    'label'    => esc_html__( 'Google Plus', 'weeland' ),
    'section'  => 'share_buttons',
  ) );

  $wp_customize->add_setting( 'display_pinterest_share_button',
    array(
      'default' => 1,
      'sanitize_callback' => 'weeland_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_pinterest_share_button', array(
    'type'     => 'checkbox',
    'priority' => 10,
    'label'    => esc_html__( 'Pinterest', 'weeland' ),
    'section'  => 'share_buttons',
  ) );
  
  /*
   * Footer
   */  
  $wp_customize->add_section( 'footer',
    array(
      'title' => esc_html__( 'Footer', 'weeland' )
    )
  ); 

  $wp_customize->add_setting(
    'copyright',
    array(
      'default' => '',
      'sanitize_callback' => 'weeland_textarea_sanitize',
    )
  );
 
  $wp_customize->add_control(
      'copyright',
      array(
        'type'    => 'textarea',
        'label'   => esc_html__( 'Copyright', 'weeland' ),
        'description' => esc_html__( 'You may use these HTML tags and attributes: a[href,title], p, b, strong, em, i, br, span, img[src, alt, title]', 'weeland' ),
        'section' => 'footer',
      )
  );
	
  /*
   * Other Options
   */    
  $wp_customize->add_section( 'other_options',
    array(
      'title' => esc_html__( 'Other Options', 'weeland' )
    )
  ); 
}
add_action( 'customize_register', 'weeland_customize_register' );

/**
 * Binds JS handlers to make the Customizer preview reload changes asynchronously.
 *
 * @since Weeland 1.0
 */
function weeland_customize_preview_js() {
	wp_enqueue_script( 'weeland-customize-preview', get_template_directory_uri() . '/assets/js/admin/customize-preview.js', array( 'customize-preview' ), '20182704', true );
}
add_action( 'customize_preview_init', 'weeland_customize_preview_js' );

if ( ! function_exists( 'weeland_textarea_sanitize' ) ) :
  /**
   * Sanitization callback for textarea field.
   *
   * @since Weeland 1.0
   * @return string Textarea value.
   */
  function weeland_textarea_sanitize( $value ) {
    if ( !current_user_can('unfiltered_html') )
			$value  = stripslashes( wp_filter_post_kses( addslashes( $value ) ) ); // wp_filter_post_kses() expects slashed

    return $value;
  }
endif;

if ( ! function_exists( 'weeland_checkbox_sanitize' ) ) :
  /**
   * Sanitization callback for checkbox.
   *
   * @since Weeland 1.0
   */
  function weeland_checkbox_sanitize( $value ) {
    if ( $value == 1 ) {
        return 1;
    } else {
        return '';
    }
  }
endif;

if ( ! function_exists( 'weeland_email_sanitize' ) ) :
  /**
   * Sanitization callback for email field.
   *
   * @since Weeland 1.0
   * @return string|null Verified email adress or null.
   */
  function weeland_email_sanitize( $value ) {
    return ( is_email( $value ) ) ? $value : '';
  }
endif;

if ( ! function_exists( 'weeland_logo_size_sanitize' ) ) :
  /**
   * Sanitization callback for width range slider.
   *
   * @since Weeland 1.0
   */
  function weeland_logo_size_sanitize( $value ) {
    if ( is_numeric( $value ) && $value >= 50 && $value <= 500 )
      return $value;

    return 200;
  }
endif;

if ( ! function_exists( 'weeland_blackout_sanitize' ) ) :
  /**
   * Sanitization callback for opacity range slider.
   *
   * @since Weeland 1.0
   */
  function weeland_blackout_sanitize( $value ) {
    if ( is_numeric( $value ) && $value >= 0 && $value <= 1 )
      return $value;

    return 0.35;
  }
endif;

if ( ! function_exists( 'weeland_grid_summary_sanitize' ) ) :
  /**
   * Sanitization callback for "summary" select.
   *
   * @since Weeland 1.0
   */
  function weeland_grid_summary_sanitize( $value ) {
    $allowed = array( 'excerpt', 'more', 'disable' );
    if ( ! in_array( $value, $allowed ) ) {
      $value = 'excerpt';
    }

    return $value;
  }
endif;

if ( ! function_exists( 'weeland_related_by_sanitize' ) ) :
  /**
   * Sanitization callback for "related by" select.
   *
   * @since Weeland 1.1
   */
  function weeland_related_by_sanitize( $value ) {
    $related_bys = array( 'category', 'tags', 'none' );
    if ( ! in_array( $value, $related_bys ) ) {
      $value = 'category';
    }

    return $value;
  }
endif;
?>