<?php
/**
 * Theme Widgets
 *
 * @package WordPress
 * @since Weeland 1.0
 */

/**
 * Weeland Instagram Widget
 *
 * Display Instagram feed in your blog.
 *
 * @since Weeland 1.0
 */
class Weeland_Instagram_Widget extends WP_Widget {
  /**
	 * Constructor.
	 */
	public function __construct() {
		parent::__construct( 'weeland-instagram-feed', esc_html__( 'Instagram', 'weeland' ), array(
			'classname'   => 'weeland-instagram-feed',
			'description' => esc_html__( 'Widget displays latest Instagram images.', 'weeland' ),
		) );
	}

	function widget( $args, $instance ) {

		extract( $args, EXTR_SKIP );

		$title    = empty( $instance['title'] ) ? '' : apply_filters( 'widget_title', $instance['title'] );
		$username = empty( $instance['username'] ) ? '' : $instance['username'];
		$number   = empty( $instance['number'] ) ? 9 : absint( $instance['number'] );
		$columns  = empty( $instance['cols'] ) ? 3 : absint( $instance['cols'] );

		echo wp_kses( 
      $args['before_widget'],
      array(
        'aside' => array(
          'id' => true,
          'class' => true
        )
      )
    );
		
		if ( ! empty( $title ) ) {
			printf( '%s%s%s', $args['before_title'], $title, $args['after_title'] );
		} 

		if ( $username && $number ) {

			$instagram_items = $this->parse_instagram( $username );
			$instagram_items = array_slice( $instagram_items, 0, $number );

			if ( is_wp_error( $instagram_items ) ) {
			   printf( '<div class="error-message">%s</div>', $instagram_items->get_error_message() );
      		} else {
      
	        	$intagram_output = '';
	        
		        foreach ( $instagram_items as $item ) {
		          $intagram_output .= sprintf( '<li><a href="%s" target="_blank" rel="nofollow"><img src="%s" alt="%s" title="%s" /></a></li>', esc_url( $item['link'] ), esc_url( $item['thumbnail'] ), esc_attr( $item['description'] ), esc_attr( $item['description'] ) );
		        } 
		        
		        if( $intagram_output ) {
		          printf( '<ul class="instagram-pics clearfix %1$s">%2$s</ul>', $columns ? 'cols-' . $columns : '', $intagram_output );
		        }
      		}
		}
		
		echo wp_kses( 
      $args['after_widget'],
      array(
        'aside' => array()
      )
    );
	}

	function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, 
	      array( 
	        'title'    => esc_html__( 'Instagram', 'weeland' ), 
	        'username' => '', 
	        'number'   => 9, 
	        'cols'     => 3
	      ) 
    	);
	?>
		<p>
      <label for="<?php echo esc_attr( $this->get_field_id('title') ); ?>"><?php esc_html_e( 'Title:', 'weeland' ); ?>
        <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('title') ); ?>" name="<?php echo esc_attr( $this->get_field_name('title') ); ?>" type="text" value="<?php echo esc_attr( $instance['title'] ); ?>" />
      </label>
    </p>
    
		<p>
      <label for="<?php echo esc_attr( $this->get_field_id('username') ); ?>"><?php esc_html_e( 'Username:', 'weeland' ); ?> 
        <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('username') ); ?>" name="<?php echo esc_attr( $this->get_field_name('username') ); ?>" type="text" value="<?php echo esc_attr( $instance['username'] ); ?>" />
      </label>
    </p>
    
		<p>
      <label for="<?php echo esc_attr( $this->get_field_id('number') ); ?>"><?php esc_html_e( 'Number of photos:', 'weeland' ); ?> 
        <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('number') ); ?>" name="<?php echo esc_attr( $this->get_field_name('number') ); ?>" type="text" value="<?php echo absint( $instance['number'] ); ?>" />
      </label>
    </p>
    
    <p>
      <label for="<?php echo esc_attr( $this->get_field_id('cols') ); ?>"><?php esc_html_e( 'Columns:', 'weeland' ); ?> 
        <select class="widefat" id="<?php echo esc_attr( $this->get_field_id('cols') ); ?>" name="<?php echo esc_attr( $this->get_field_name('cols') ); ?>">
          <option value="2" <?php selected( absint( $instance['cols'] ), 2 ); ?>>2</option>
          <option value="3" <?php selected( absint( $instance['cols'] ), 3 ); ?>>3</option>
          <option value="4" <?php selected( absint( $instance['cols'] ), 4 ); ?>>4</option>
        </select>
      </label>
    </p>
		<?php
	}

	function update( $new_instance, $instance ) {
		$instance['title']    = strip_tags( $new_instance['title'] );
		$instance['username'] = trim( strip_tags( $new_instance['username'] ) );
		$instance['number']   = $new_instance['number'] ? absint( $new_instance['number'] ) : 9;
		$instance['cols']     = $new_instance['cols'] ? absint( $new_instance['cols'] ) : 9;
		return $instance;
	}

// based on https://gist.github.com/cosmocatalano/4544576.
  // https://github.com/scottsweb/wp-instagram-widget
  function parse_instagram( $username ) {

    $username = trim( strtolower( $username ) );

      switch ( substr( $username, 0, 1 ) ) {
        case '#':
          $url              = 'https://instagram.com/explore/tags/' . str_replace( '#', '', $username );
          $transient_prefix = 'h';
          break;

        default:
          $url              = 'https://instagram.com/' . str_replace( '@', '', $username );
          $transient_prefix = 'u';
          break;
      }

      if ( false === ( $instagram = get_transient( 'insta-a10-' . $transient_prefix . '-' . sanitize_title_with_dashes( $username ) ) ) ) {

        $remote = wp_remote_get( $url );

        if ( is_wp_error( $remote ) ) {
          return new WP_Error( 'site_down', esc_html__( 'Unable to communicate with Instagram.', 'weeland' ) );
        }

        if ( 200 !== wp_remote_retrieve_response_code( $remote ) ) {
          return new WP_Error( 'invalid_response', esc_html__( 'Instagram did not return a 200.', 'weeland' ) );
        }

        $shards      = explode( 'window._sharedData = ', $remote['body'] );
        $insta_json  = explode( ';</script>', $shards[1] );
        $insta_array = json_decode( $insta_json[0], true );

        if ( ! $insta_array ) {
          return new WP_Error( 'bad_json', esc_html__( 'Instagram has returned invalid data.', 'weeland' ) );
        }

        if ( isset( $insta_array['entry_data']['ProfilePage'][0]['graphql']['user']['edge_owner_to_timeline_media']['edges'] ) ) {
          $images = $insta_array['entry_data']['ProfilePage'][0]['graphql']['user']['edge_owner_to_timeline_media']['edges'];
        } elseif ( isset( $insta_array['entry_data']['TagPage'][0]['graphql']['hashtag']['edge_hashtag_to_media']['edges'] ) ) {
          $images = $insta_array['entry_data']['TagPage'][0]['graphql']['hashtag']['edge_hashtag_to_media']['edges'];
        } else {
          return new WP_Error( 'bad_json_2', esc_html__( 'Instagram has returned invalid data.', 'weeland' ) );
        }

        if ( ! is_array( $images ) ) {
          return new WP_Error( 'bad_array', esc_html__( 'Instagram has returned invalid data.', 'weeland' ) );
        }

        $instagram = array();

        foreach ( $images as $image ) {
          if ( true === $image['node']['is_video'] ) {
            $type = 'video';
          } else {
            $type = 'image';
          }

          $caption = __( 'Instagram Image', 'weeland' );
          if ( ! empty( $image['node']['edge_media_to_caption']['edges'][0]['node']['text'] ) ) {
            $caption = wp_kses( $image['node']['edge_media_to_caption']['edges'][0]['node']['text'], array() );
          }

          $instagram[] = array(
            'description' => $caption,
            'link'        => trailingslashit( '//instagram.com/p/' . $image['node']['shortcode'] ),
            'time'        => $image['node']['taken_at_timestamp'],
            'comments'    => $image['node']['edge_media_to_comment']['count'],
            'likes'       => $image['node']['edge_liked_by']['count'],
            'thumbnail'   => preg_replace( '/^https?\:/i', '', $image['node']['thumbnail_resources'][0]['src'] ),
            'small'       => preg_replace( '/^https?\:/i', '', $image['node']['thumbnail_resources'][2]['src'] ),
            'large'       => preg_replace( '/^https?\:/i', '', $image['node']['thumbnail_resources'][4]['src'] ),
            'original'    => preg_replace( '/^https?\:/i', '', $image['node']['display_url'] ),
            'type'        => $type,
          );
        } // End foreach().

        // do not set an empty transient - should help catch private or empty accounts.
        if ( ! empty( $instagram ) ) {
          $instagram = serialize( $instagram );
          set_transient( 'insta-a10-' . $transient_prefix . '-' . sanitize_title_with_dashes( $username ), $instagram, apply_filters( 'weeland_instagram_cache_time', HOUR_IN_SECONDS * 2 ) );
        }
      }

      if ( ! empty( $instagram ) ) {
        return unserialize( $instagram );
      } else {
        return new WP_Error( 'no_images', esc_html__( 'Instagram did not return any images.', 'weeland' ) );
      }
  	}
}
?>